@@ -1,7 +1,7 @@
 __author__ = 'Altertech, http://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2018-2020 Altertech Group'
 __license__ = 'Apache License 2.0'
-__version__ = '2.0.44'
+__version__ = '2.0.45'
 
 from flask import request, jsonify, Response, abort, send_file, make_response
 from flask_restx import Api, Resource, reqparse
@@ -41,11 +41,14 @@ from .core import bucket_get, bucket_touch
 from .core import rq
 
 from functools import wraps
+from types import SimpleNamespace
 
 from pyaltt2.network import netacl_match
 
 success = {'ok': True}
 
+_d = SimpleNamespace(api=None)
+
 filters = []
 """
 custom filter is a method defined as:
@@ -69,13 +72,15 @@ exception
 
 
 def arr_from_str(s):
-    if not isinstance(s, str) or s.find('|') == -1: return s
+    if not isinstance(s, str) or s.find('|') == -1:
+        return s
     result = []
     vals = s.split('|')
     for v in vals:
         try:
             _v = float(v)
-            if _v == int(_v): _v = int(_v)
+            if _v == int(_v):
+                _v = int(_v)
         except:
             _v = v
         result.append(_v)
@@ -84,9 +89,11 @@ def arr_from_str(s):
 
 # throws exception
 def dict_from_str(s, spl=','):
-    if not isinstance(s, str): return s
+    if not isinstance(s, str):
+        return s
     result = {}
-    if not s: return result
+    if not s:
+        return result
     vals = s.split(spl)
     for v in vals:
         name, value = v.split('=')
@@ -103,13 +110,18 @@ def dict_from_str(s, spl=','):
         if isinstance(value, str):
             try:
                 value = float(value)
-                if value == int(value): value = int(value)
+                if value == int(value):
+                    value = int(value)
             except:
                 pass
         result[name] = value
     return result
 
 
+def get_api():
+    return _d.api
+
+
 def _response_new_location(payload, code, new_id, resource):
     r = jsonify(payload) if payload else Response()
     r.status_code = code
@@ -197,10 +209,21 @@ api_uri = '/manage'
 api_uri_rest = f'{api_uri}/v2'
 
 
+def render_roboger_root():
+    abort(404)
+
+
+class RobogerApi(Api):
+
+    def render_root(self):
+        return render_roboger_root()
+
+
 def init():
     app = get_app()
 
-    api = Api(app=app)
+    api = RobogerApi(app=app, doc=core_config.get('api-doc', '/'))
+    _d.api = api
     ns_public = api.namespace('/', description='Public functions')
 
     @ns_public.route('/ping')
@@ -597,6 +620,9 @@ def _process_addr(a):
 def test(**kwargs):
     result = success.copy()
     result.update({'version': product.version, 'build': product.build})
+    if request.headers.get('X-Auth-Key',
+                           kwargs.get('k')) == core_config['master']['key']:
+        result['master'] = True
     return jsonify(result)
 
 
@@ -1125,12 +1151,16 @@ def m_endpoint_data(endpoint_id,
     cfg = endpoint['config']
     plugin_name = endpoint['plugin_name']
     if plugin_name == 'email':
-        if data: cfg['rcpt'] = data
+        if data:
+            cfg['rcpt'] = data
     elif plugin_name == 'slack':
-        if data: cfg['url'] = data
-        if data2: cfg['rich'] = data2 != 'plain'
+        if data:
+            cfg['url'] = data
+        if data2:
+            cfg['rich'] = data2 != 'plain'
     elif plugin_name == 'telegram':
-        if data: cfg['chat_id'] = data
+        if data:
+            cfg['chat_id'] = data
     try:
         endpoint_update(endpoint_id, data={'config': cfg})
     except LookupError:
