@@ -1,7 +1,7 @@
 __author__ = 'Altertech, http://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2018-2020 Altertech Group'
 __license__ = 'Apache License 2.0'
-__version__ = '2.0.44'
+__version__ = '2.0.45'
 
 import platform
 import os
@@ -54,6 +54,9 @@ SERVER_CONFIG_SCHEMA = {
                 'ip-header': {
                     'type': 'string',
                 },
+                'api-doc': {
+                    'type': ['boolean', 'string'],
+                },
                 'limits': {
                     'type': 'object',
                     'properties': {
