@@ -44,3 +44,8 @@ def send(config, **kwargs):
 
 def validate_config(config, **kwargs):
     validate(config, schema=PROPERTY_MAP_SCHEMA)
+
+
+def validate_plugin_config(plugin_config, **kwargs):
+    if plugin_config:
+        raise ValueError('this plugin should have no configuration options')
